package com.jjt.order.service.impl;

import java.util.List;
import org.springframework.stereotype.Service;
import com.jjt.order.mapper.TwinBomMapper;
import com.jjt.order.domain.TwinBom;
import com.jjt.order.service.ITwinBomService;
import javax.annotation.Resource;

/**
 * 物料管理Service业务层处理
 *
 * @author wukai
 * @date 2025-01-16
 */
@Service
public class TwinBomServiceImpl implements ITwinBomService {
    @Resource
    private TwinBomMapper twinBomMapper;

    /**
     * 查询物料管理
     *
     * @param bomId 物料管理主键
     * @return 物料管理
     */
    @Override
    public TwinBom selectTwinBomByBomId(Long bomId) {
        return twinBomMapper.selectTwinBomByBomId(bomId);
    }

    /**
     * 查询物料管理列表
     *
     * @param twinBom 物料管理
     * @return 物料管理
     */
    @Override
    public List<TwinBom> selectTwinBomList(TwinBom twinBom) {
        return twinBomMapper.selectTwinBomList(twinBom);
    }

    /**
     * 新增物料管理
     *
     * @param twinBom 物料管理
     * @return 结果
     */
    @Override
    public int insertTwinBom(TwinBom twinBom) {
            return twinBomMapper.insertTwinBom(twinBom);
    }

    /**
     * 修改物料管理
     *
     * @param twinBom 物料管理
     * @return 结果
     */
    @Override
    public int updateTwinBom(TwinBom twinBom) {
        return twinBomMapper.updateTwinBom(twinBom);
    }

    /**
     * 批量删除物料管理
     *
     * @param bomIds 需要删除的物料管理主键
     * @return 结果
     */
    @Override
    public int deleteTwinBomByBomIds(Long[] bomIds) {
        return twinBomMapper.deleteTwinBomByBomIds(bomIds);
    }

    /**
     * 删除物料管理信息
     *
     * @param bomId 物料管理主键
     * @return 结果
     */
    @Override
    public int deleteTwinBomByBomId(Long bomId) {
        return twinBomMapper.deleteTwinBomByBomId(bomId);
    }
}
